@@ -136,3 +136,6 @@ class DecoratorModel:
                              for seq in torch.cat(sequences, 1).data.cpu().numpy()]
         scaffold_smiles = [self.vocabulary.decode_scaffold(seq) for seq in scaffold_seqs.data.cpu().numpy()]
         return zip(scaffold_smiles, decoration_smiles, nlls.data.cpu().numpy().tolist())
+
+    def get_network_parameters(self):
+        return self.network.parameters()
