@@ -11,10 +11,6 @@ class LibInventAdapter(GenerativeModelBase):
         self.max_sequence_length = self.generative_model.max_sequence_length
         self.network = self.generative_model.network
 
-    # TODO: this should not be part of the interface
-    def load_from_file(self, path, mode=ModelModeEnum().TRAINING):
-        return self.generative_model.load_from_file(path, mode=mode)
-
     def save_to_file(self, path):
         self.generative_model.save_to_file(path)
 
@@ -26,3 +22,9 @@ class LibInventAdapter(GenerativeModelBase):
 
     def set_mode(self, mode: str):
         self.generative_model.set_mode(mode)
+
+    def get_network_parameters(self):
+        return self.generative_model.get_network_parameters()
+
+    def get_vocabulary(self):
+        return self.vocabulary
