@@ -19,8 +19,8 @@ class ReinventCoreAdapter(GenerativeModelBase):
     def likelihood(self, sequences):
         return self.generative_model.likelihood(sequences)
 
-    def sample(self, num, batch_size):
-        return self.generative_model.sample_smiles(num, batch_size)
+    def sample(self, batch_size):
+        return self.generative_model.sample_sequences_and_smiles(batch_size)
 
     def get_network_parameters(self):
         return self.generative_model.get_network_parameters()
